@@ -12,6 +12,18 @@ def vektorizeNormalization(dm, profitcost):
              dm_norm[i] = 1- (dm[i] / squared(dm[i]).sum(axis=0)**0.5)
     return dm_norm
 
+def simpleLinearNormalization(df, focus):
+    df_norm = df.copy()
+    for i in range(0,len(focus.columns)):
+        col_name = "k" + str(i+1)
+        if focus.iloc[0,i] == "max":
+            k = df.iloc[:,i].min()
+            df_norm[col_name] = k / df.iloc[:,i]
+        elif focus.iloc[0,i] == "min":
+            k = df.iloc[:,i].max()
+            df_norm[col_name] = df.iloc[:,i] / k
+    return df_norm
+
 def compromiseNormalization(dm, profitcost):
     dm_norm = pd.DataFrame()
     for j in range(0,len(profitcost.columns)):
